/*
 *  layout_tags.h : Some XML tags that are shared between several files.
 *                  This file is part of the FreeLCD package.
 *
 *  $Id: layout_tags.h,v 1.3 2004/06/20 14:44:51 unicorn Exp $
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *  Copyright (c) 2003, Jeroen van den Berg <unicorn@hippie.nu>
 */

/** \file layout_tags.h
 * Some XML tags and attributes that are used in several places. They are
 * used in describing screen layouts.
 */

#ifndef _LAYOUT_TAGS_H
#define _LAYOUT_TAGS_H 1

typedef enum
{
  ROW = 200, COL, FIELD, LABEL, HSCROLL, VSCROLL
} 
tag_t;

typedef enum
{
  TYPE = 200, ID, NAME, VALIGN, HALIGN, EXPAND, FORMAT, TIMEZONE,
  SCROLL
}
attr_t;

#endif
